@@ -20,14 +20,10 @@ from __future__ import annotations
 import time
 from typing import Any
 
-from datadog import api, initialize  # type: ignore[attr-defined]
+from datadog import api, initialize
 
 from airflow.exceptions import AirflowException
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.common.compat.sdk import BaseHook
 from airflow.utils.log.logging_mixin import LoggingMixin
 
 
